#!/usr/bin/python
import sys
import subprocess
import yaml

FORMATS = {
    "S16_LE": "S16LE",
    "S24_LE": "S24LE",
    "S24_3LE": "S24LE3",
    "S32_LE": "S32LE",
    "FLOAT_LE": "FLOAT32LE",
    "FLOAT64_LE": "FLOAT64LE",
}

def main():
    rate = sys.argv[1]
    fmt = sys.argv[2]
    channels = sys.argv[3]
    configfile = sys.argv[4]

    with open(configfile) as f:
        config = yaml.load(f, Loader=yaml.SafeLoader)

    if config["devices"].get("enable_resampling", False): 
        config["devices"]["capture_samplerate"] = int(rate)
    else:
        config["devices"]["samplerate"] = int(rate)

    config["devices"]["capture"]["type"] = "Stdin"
    config["devices"]["capture"]["format"] = FORMATS[fmt]
    if config["devices"]["capture"]["channels"] != int(channels):
        print(f'Wrong number of channels, got: {channels} expected: {config["devices"]["capture"]["channels"]}', file=sys.stderr)
        return


    with open(r"/tmp/camilladsp.yml", "w") as f:
        yaml.dump(config, f)

    print(f"Rate: {rate}, format: {fmt}, channels: {channels}", file=sys.stderr)
    #aplay --quiet -D hw:1,0 -r 44100 -f S32_LE -c 2
    subprocess.run(["/path/to/camilladsp", "-p1234", "/tmp/camilladsp.yml"], stdin=sys.stdin.buffer)


if __name__ == "__main__":
    main()
